# user_caller.py
# !/usr/bin/env python3
"""Library with user class used for jwt authentication.
Available class:
- User: user object for REST API authentication.
"""

import json
from datetime import datetime
from typing import Union

import jwt
import requests

from ..utils import validate_email


class User:
    """
    User class providing information for current user.
    attributes: email, password, server
    """

    def __init__(self, email: str, password: str, server: str):

        if email == "host" or validate_email(email):
            self.server = server  # api address
            self.email = email  # tested email
            self._password = password  # user password
            # params obtained by server
            self.jwt, self.id, self.expire_at = self._sign_in()  # /api/jwt
            # if obtained then success print
            print(f"User {self.email} logged in: {datetime.utcnow()}")
        else:
            raise ValueError("Wrong email format.")

    def __str__(self):
        return f"User {self.id}"

    def __repr__(self):
        return f"<User {self.id}>"

    def _sign_in(self) -> Union[tuple, Exception]:
        """
        Sign in method for USER or HOST account.
        :return: JWT string, user id and expired at if logged in or Exception if login failed
        """
        header = {"Content-type": "application/json", "Accept": "text/plain"}

        if self.email != "host":
            response = requests.put(
                f"{self.server}/jwt",
                data=json.dumps({"login": self.email, "password": self._password}),
                headers=header,
            )
        else:
            response = requests.post(f"{self.server}/jwt", headers=header)

        if response.status_code == 201:
            jwt_token = response.text
            data = jwt.decode(
                jwt_token, verify=False
            )  # decode jwt token to obtain id and expire date
            return jwt_token, data["id"], data["exp"]
        else:
            raise ValueError("Wrong user email or password.")
