# api_interface.py
# !/usr/bin/env python3
"""Library with Api abstract class.
Available classes:
ApiInterface - abstract metaclass for another interfaces
"""

from typing import List, Union
import pandas as pd

from abc import ABCMeta, abstractmethod


class ApiInterface(metaclass=ABCMeta):
    """Interface for api endpoint caller has to have at least this methods"""

    @abstractmethod
    def load_all(self, filter_tag: List[str]) -> pd.DataFrame:
        raise NotImplementedError("You should implement this!")

    @abstractmethod
    def load_by_id(self, id: str) -> pd.DataFrame:
        raise NotImplementedError("You should implement this!")

    @abstractmethod
    def delete(self, obj: Union[pd.DataFrame, pd.Series]):
        raise NotImplementedError("You should implement this!")
